==> lori_sdk-0.0.1.tar.gz: lib/data/models/cart/cart.dart <==
import 'dart:convert';

import 'package:json_annotation/json_annotation.dart';
import 'package:lori_sdk/data/models/cart/cartItem.dart';
import 'package:lori_sdk/data/models/cart/freight.dart';
import 'package:lori_sdk/data/models/cart/paymentMethod.dart';
import 'package:lori_sdk/data/models/cart/seller.dart';
import 'package:lori_sdk/data/models/cart/voucher.dart';
import 'package:lori_sdk/data/models/userAddress.dart';
part 'cart.g.dart';

final String tableName = 'cart';
final String columnId = 'id';
final String columnCpf = 'cpf';
final String columnDiscountValue = 'discount_value';
final String columnFreightValue = 'freight_value';
final String columnFeeValue = 'fee_value';
final String columnSubTotal = 'sub_total';
final String columnTotal = 'total';
final String columnSubTotalSeparated = 'sub_total_separated';
final String columnTotalSeparated = 'total_separated';
final String columnMaxInstallments = 'max_installments';
final String columnInstallments = 'installments';
final String columnFreight = 'freight';
final String columnDeliveryAddress = 'delivery_address';
final String columnIsDelivery = 'is_delivery';
final String columnDeliveryTime = 'delivery_time';
final String columnLatitude = 'latitude';
final String columnLongitude = 'longitude';
final String columnCep = 'cep';
final String columnCpfInvoice = 'cpf_invoice';
final String columnCpfPickup = 'cpf_pickup';
final String columnItems = 'items';
final String columnSeller = 'seller';
final String columnPaymentMethod = 'payment_method';
final String columnSupportedPaymentMethods = 'supported_payment_methods';
final String columnVoucher = 'voucher';
final String columnIsCvvValidated = 'is_cvv_validated';
final String columnHasFeeInstallment = 'has_fee_installment';

@JsonSerializable()
class Cart {

  Cart();

  String id;
  String cpf;

  double discountAmount;
  double freightAmount;
  double feeAmount;
  double subTotalAmount;
  double totalAmount;
  double subTotalSeparatedAmount;
  double totalSeparatedAmount;

  int maxInstallments;
  int installments;

  Freight freight;
  UserAddress deliveryAddress;
  bool isDelivery;
  int deliveryTime;

  double latitude;
  double longitude;

  String cep;

  String cpfInvoice;
  String cpfPickUp;

  List<CartItem> items;
  Seller seller;
  PaymentMethod paymentMethod;

  List<PaymentMethodType> supportedPaymentMethods;

  //Added this getter as a workaround to support a default value
  //If the API DOES NOT return a supportedPaymentMethods list on the cart the default will be [.credit]
  //But for some reason dart did not allow us to give a list on the defaultValue of the JsonKey...
  List<PaymentMethodType> get supportedPaymentTypes {
    return supportedPaymentMethods == null ? [PaymentMethodType.credit] : supportedPaymentMethods;
  }
  set supportedPaymentTypes(List<PaymentMethodType> methods) {
    if (methods != null) {
      supportedPaymentMethods = methods;
    }
  }

  Voucher voucher;

  bool isCvvValidated;
  bool hasFeeInstallment = false;

  factory Cart.fromJson(Map<String, dynamic> json) => _$CartFromJson(json);
  Map<String, dynamic> toJson() => _$CartToJson(this);

  // Helpers method to support SQLite
  Map<String, dynamic> toMap() {
    var map = <String, dynamic> {
      columnId: id,
      columnCpf: cpf,
      columnDiscountValue: discountAmount,
      columnFreightValue: freightAmount,
      columnFeeValue: feeAmount,
      columnSubTotal: subTotalAmount,
      columnTotal: totalAmount,
      columnSubTotalSeparated: subTotalSeparatedAmount,
      columnTotalSeparated: totalSeparatedAmount,
      columnMaxInstallments: maxInstallments,
      columnInstallments: installments,
      columnFreight: json.encode(freight),
      columnDeliveryAddress: json.encode(deliveryAddress),
      columnIsDelivery: isDelivery ? 1 : 0,
      columnDeliveryTime: deliveryTime,
      columnLatitude: latitude,
      columnLongitude: longitude,
      columnCep: cep,
      columnCpfInvoice: cpfInvoice,
      columnCpfPickup: cpfPickUp,
      columnItems: json.encode(items),
      columnSeller: json.encode(seller),
      columnPaymentMethod: json.encode(paymentMethod),
      columnSupportedPaymentMethods: json.encode(supportedPaymentTypes.map((pm) => pm.index).toList()),
      columnVoucher: json.encode(voucher),
      columnIsCvvValidated: isCvvValidated ? 1 : 0,
      columnHasFeeInstallment: hasFeeInstallment ? 1 : 0,
    };
    return map;
  }

  void fromMap(Map<String, dynamic> map) {
    id = map[columnId];
    cpf = map[columnCpf];
    discountAmount = map[columnDiscountValue];
    freightAmount = map[columnFreightValue];
    feeAmount = map[columnFeeValue];
    subTotalAmount = map[columnSubTotal];
    totalAmount = map[columnTotal];
    subTotalSeparatedAmount = map[columnSubTotalSeparated];
    totalSeparatedAmount = map[columnTotalSeparated];
    maxInstallments = map[columnMaxInstallments];
    installments = map[columnInstallments];
    isDelivery = map[columnIsDelivery] == 1 ? true : false;
    deliveryTime = map[columnDeliveryTime];
    latitude = map[columnLatitude];
    longitude = map[columnLongitude];
    cep = map[columnCep];
    cpfInvoice = map[columnCpfInvoice];
    cpfPickUp = map[columnCpfPickup];

    // Custom objects fetching
    Iterable iItems = json.decode(map[columnItems]);
    List<CartItem> cartItems = [];
    iItems.forEach((map) {
      CartItem item = CartItem.fromJson(map);
      item.migrateToCurrentVersion();
      cartItems.add(item);
    });
    items = cartItems;

    freight = map[columnFreight] == 'null' ? null : Freight.fromJson(json.decode(map[columnFreight]));
    deliveryAddress = map[columnDeliveryAddress] == 'null' ? null : UserAddress.fromJson(json.decode(map[columnDeliveryAddress]));
    seller = map[columnSeller] == 'null' ? null : Seller.fromJson(json.decode(map[columnSeller]));
    paymentMethod = map[columnPaymentMethod] == 'null' ? null : PaymentMethod.fromJson(json.decode(map[columnPaymentMethod]));

    if (map[columnSupportedPaymentMethods] != null) {
      Iterable pItems = json.decode(map[columnSupportedPaymentMethods]);
      List<PaymentMethodType> supportedPayments = [];
      if (pItems != null) {
        pItems.forEach((map) {
          supportedPayments.add(PaymentMethodType.values[map]);
        });
      }
      supportedPaymentTypes = supportedPayments;
    }

    voucher = map[columnVoucher] == 'null' ? null : Voucher.fromJson(json.decode(map[columnVoucher]));
    isCvvValidated = map[columnIsCvvValidated] == 1 ? true : false;
    hasFeeInstallment = map[columnHasFeeInstallment] == 1 ? true : false;
  }

}

==> lori_sdk-0.1.10.tar.gz: lib/data/models/cart/cart.dart <==
import 'dart:convert';

import 'package:json_annotation/json_annotation.dart';
import 'package:lori_sdk/data/models/cart/cartItem.dart';
import 'package:lori_sdk/data/models/cart/freight.dart';
import 'package:lori_sdk/data/models/cart/paymentMethod.dart';
import 'package:lori_sdk/data/models/cart/seller.dart';
import 'package:lori_sdk/data/models/cart/voucher.dart';
import 'package:lori_sdk/data/models/userAddress.dart';

part 'cart.g.dart';

final String tableName = 'cart';
final String columnId = 'id';
final String columnCpf = 'cpf';
final String columnDiscountValue = 'discount_value';
final String columnFreightValue = 'freight_value';
final String columnFeeValue = 'fee_value';
final String columnSubTotal = 'sub_total';
final String columnTotal = 'total';
final String columnSubTotalSeparated = 'sub_total_separated';
final String columnTotalSeparated = 'total_separated';
final String columnMaxInstallments = 'max_installments';
final String columnInstallments = 'installments';
final String columnFreight = 'freight';
final String columnDeliveryAddress = 'delivery_address';
final String columnIsDelivery = 'is_delivery';
final String columnDeliveryTime = 'delivery_time';
final String columnLatitude = 'latitude';
final String columnLongitude = 'longitude';
final String columnCep = 'cep';
final String columnCpfInvoice = 'cpf_invoice';
final String columnCpfPickup = 'cpf_pickup';
final String columnItems = 'items';
final String columnSeller = 'seller';
final String columnPaymentMethod = 'payment_method';
final String columnSupportedPaymentMethods = 'supported_payment_methods';
final String columnVoucher = 'voucher';
final String columnIsCvvValidated = 'is_cvv_validated';
final String columnHasFeeInstallment = 'has_fee_installment';

@JsonSerializable()
class Cart {
  Cart();

  String id;
  String cpf;

  double discountAmount;
  double freightAmount;
  double feeAmount;
  double subTotalAmount;
  double totalAmount;
  double subTotalSeparatedAmount;
  double totalSeparatedAmount;

  int maxInstallments;
  int installments;

  Freight freight;
  UserAddress deliveryAddress;
  bool isDelivery;
  int deliveryTime;

  double latitude;
  double longitude;

  String cep;

  String cpfInvoice;
  String cpfPickUp;

  List<CartItem> items;
  Seller seller;
  PaymentMethod paymentMethod;

  List<PaymentMethodType> supportedPaymentMethods;

  //Added this getter as a workaround to support a default value
  //If the API DOES NOT return a supportedPaymentMethods list on the cart the default will be [.credit]
  //But for some reason dart did not allow us to give a list on the defaultValue of the JsonKey...
  List<PaymentMethodType> get supportedPaymentTypes {
    return supportedPaymentMethods == null
        ? [PaymentMethodType.credit]
        : supportedPaymentMethods;
  }

  set supportedPaymentTypes(List<PaymentMethodType> methods) {
    if (methods != null) {
      supportedPaymentMethods = methods;
    }
  }

  Voucher voucher;

  bool isCvvValidated;
  bool hasFeeInstallment = false;

  factory Cart.fromJson(Map<String, dynamic> json) => _$CartFromJson(json);

  Map<String, dynamic> toJson() => _$CartToJson(this);

  // Helpers method to support SQLite
  Map<String, dynamic> toMap() {
    var map = <String, dynamic>{
      columnId: id,
      columnCpf: cpf,
      columnDiscountValue: discountAmount,
      columnFreightValue: freightAmount,
      columnFeeValue: feeAmount,
      columnSubTotal: subTotalAmount,
      columnTotal: totalAmount,
      columnSubTotalSeparated: subTotalSeparatedAmount,
      columnTotalSeparated: totalSeparatedAmount,
      columnMaxInstallments: maxInstallments,
      columnInstallments: installments,
      columnFreight: json.encode(freight),
      columnDeliveryAddress: json.encode(deliveryAddress),
      columnIsDelivery: isDelivery ? 1 : 0,
      columnDeliveryTime: deliveryTime,
      columnLatitude: latitude,
      columnLongitude: longitude,
      columnCep: cep,
      columnCpfInvoice: cpfInvoice,
      columnCpfPickup: cpfPickUp,
      columnItems: json.encode(items),
      columnSeller: json.encode(seller),
      columnPaymentMethod: json.encode(paymentMethod),
      columnSupportedPaymentMethods:
          json.encode(supportedPaymentTypes.map((pm) => pm.index).toList()),
      columnVoucher: json.encode(voucher),
      columnIsCvvValidated: isCvvValidated ? 1 : 0,
      columnHasFeeInstallment: hasFeeInstallment ? 1 : 0,
    };
    return map;
  }

  void fromMap(Map<String, dynamic> map) {
    id = map[columnId];
    cpf = map[columnCpf];
    discountAmount = map[columnDiscountValue];
    freightAmount = map[columnFreightValue];
    feeAmount = map[columnFeeValue];
    subTotalAmount = map[columnSubTotal];
    totalAmount = map[columnTotal];
    subTotalSeparatedAmount = map[columnSubTotalSeparated];
    totalSeparatedAmount = map[columnTotalSeparated];
    maxInstallments = map[columnMaxInstallments];
    installments = map[columnInstallments];
    isDelivery = map[columnIsDelivery] == 1 ? true : false;
    deliveryTime = map[columnDeliveryTime];
    latitude = map[columnLatitude];
    longitude = map[columnLongitude];
    cep = map[columnCep];
    cpfInvoice = map[columnCpfInvoice];
    cpfPickUp = map[columnCpfPickup];

    // Custom objects fetching
    Iterable iItems = json.decode(map[columnItems]);
    List<CartItem> cartItems = [];
    iItems.forEach((map) {
      CartItem item = CartItem.fromJson(map);
      item.migrateToCurrentVersion();
      cartItems.add(item);
    });
    items = cartItems;

    freight = map[columnFreight] == 'null'
        ? null
        : Freight.fromJson(json.decode(map[columnFreight]));
    deliveryAddress = map[columnDeliveryAddress] == 'null'
        ? null
        : UserAddress.fromJson(json.decode(map[columnDeliveryAddress]));
    seller = map[columnSeller] == 'null'
        ? null
        : Seller.fromJson(json.decode(map[columnSeller]));
    paymentMethod = map[columnPaymentMethod] == 'null'
        ? null
        : PaymentMethod.fromJson(json.decode(map[columnPaymentMethod]));

    if (map[columnSupportedPaymentMethods] != null) {
      Iterable pItems = json.decode(map[columnSupportedPaymentMethods]);
      List<PaymentMethodType> supportedPayments = [];
      if (pItems != null) {
        pItems.forEach((map) {
          supportedPayments.add(PaymentMethodType.values[map]);
        });
      }
      supportedPaymentTypes = supportedPayments;
    }

    voucher = map[columnVoucher] == 'null'
        ? null
        : Voucher.fromJson(json.decode(map[columnVoucher]));
    isCvvValidated = map[columnIsCvvValidated] == 1 ? true : false;
    hasFeeInstallment = map[columnHasFeeInstallment] == 1 ? true : false;
  }
}
